# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Tables.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_ModelF_ice
import omero_RTypes_ice
import omero_System_ice
import omero_Collections_ice
import omero_Repositories_ice
import omero_ServerErrors_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Included module Glacier2
_M_Glacier2 = Ice.openModule('Glacier2')

# Included module omero.grid
_M_omero.grid = Ice.openModule('omero.grid')

# Included module omero.cmd
_M_omero.cmd = Ice.openModule('omero.cmd')

# Start of module omero
__name__ = 'omero'

# Start of module omero.api
__name__ = 'omero.api'

if 'ServiceFactory' not in _M_omero.api.__dict__:
    _M_omero.api._t_ServiceFactory = IcePy.declareClass('::omero::api::ServiceFactory')
    _M_omero.api._t_ServiceFactoryPrx = IcePy.declareProxy('::omero::api::ServiceFactory')

# End of module omero.api

__name__ = 'omero'

# Start of module omero.grid
__name__ = 'omero.grid'

if 'Column' not in _M_omero.grid.__dict__:
    _M_omero.grid.Column = Ice.createTempClass()
    class Column(Ice.Object):
        """
        Base type for dealing working with tabular data. For efficiency,
        data is grouped by type, i.e. column. These value objects are passed
        through the {@code Table} interface.
        """
        def __init__(self, name='', description=''):
            self.name = name
            self.description = description

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Column')

        def ice_id(self, current=None):
            return '::omero::grid::Column'

        def ice_staticId():
            return '::omero::grid::Column'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_Column)

        __repr__ = __str__

    _M_omero.grid.ColumnPrx = Ice.createTempClass()
    class ColumnPrx(Ice.ObjectPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.ColumnPrx.ice_checkedCast(proxy, '::omero::grid::Column', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.ColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::Column'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_ColumnPrx = IcePy.defineProxy('::omero::grid::Column', ColumnPrx)

    _M_omero.grid._t_Column = IcePy.defineClass('::omero::grid::Column', Column, -1, (), False, False, None, (), (
        ('name', (), IcePy._t_string, False, 0),
        ('description', (), IcePy._t_string, False, 0)
    ))
    Column._ice_type = _M_omero.grid._t_Column

    _M_omero.grid.Column = Column
    del Column

    _M_omero.grid.ColumnPrx = ColumnPrx
    del ColumnPrx

if 'FileColumn' not in _M_omero.grid.__dict__:
    _M_omero.grid.FileColumn = Ice.createTempClass()
    class FileColumn(_M_omero.grid.Column):
        def __init__(self, name='', description='', values=None):
            _M_omero.grid.Column.__init__(self, name, description)
            self.values = values

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Column', '::omero::grid::FileColumn')

        def ice_id(self, current=None):
            return '::omero::grid::FileColumn'

        def ice_staticId():
            return '::omero::grid::FileColumn'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_FileColumn)

        __repr__ = __str__

    _M_omero.grid.FileColumnPrx = Ice.createTempClass()
    class FileColumnPrx(_M_omero.grid.ColumnPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.FileColumnPrx.ice_checkedCast(proxy, '::omero::grid::FileColumn', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.FileColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::FileColumn'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_FileColumnPrx = IcePy.defineProxy('::omero::grid::FileColumn', FileColumnPrx)

    _M_omero.grid._t_FileColumn = IcePy.defineClass('::omero::grid::FileColumn', FileColumn, -1, (), False, False, _M_omero.grid._t_Column, (), (('values', (), _M_omero.api._t_LongArray, False, 0),))
    FileColumn._ice_type = _M_omero.grid._t_FileColumn

    _M_omero.grid.FileColumn = FileColumn
    del FileColumn

    _M_omero.grid.FileColumnPrx = FileColumnPrx
    del FileColumnPrx

if 'ImageColumn' not in _M_omero.grid.__dict__:
    _M_omero.grid.ImageColumn = Ice.createTempClass()
    class ImageColumn(_M_omero.grid.Column):
        def __init__(self, name='', description='', values=None):
            _M_omero.grid.Column.__init__(self, name, description)
            self.values = values

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Column', '::omero::grid::ImageColumn')

        def ice_id(self, current=None):
            return '::omero::grid::ImageColumn'

        def ice_staticId():
            return '::omero::grid::ImageColumn'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_ImageColumn)

        __repr__ = __str__

    _M_omero.grid.ImageColumnPrx = Ice.createTempClass()
    class ImageColumnPrx(_M_omero.grid.ColumnPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.ImageColumnPrx.ice_checkedCast(proxy, '::omero::grid::ImageColumn', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.ImageColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::ImageColumn'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_ImageColumnPrx = IcePy.defineProxy('::omero::grid::ImageColumn', ImageColumnPrx)

    _M_omero.grid._t_ImageColumn = IcePy.defineClass('::omero::grid::ImageColumn', ImageColumn, -1, (), False, False, _M_omero.grid._t_Column, (), (('values', (), _M_omero.api._t_LongArray, False, 0),))
    ImageColumn._ice_type = _M_omero.grid._t_ImageColumn

    _M_omero.grid.ImageColumn = ImageColumn
    del ImageColumn

    _M_omero.grid.ImageColumnPrx = ImageColumnPrx
    del ImageColumnPrx

if 'DatasetColumn' not in _M_omero.grid.__dict__:
    _M_omero.grid.DatasetColumn = Ice.createTempClass()
    class DatasetColumn(_M_omero.grid.Column):
        def __init__(self, name='', description='', values=None):
            _M_omero.grid.Column.__init__(self, name, description)
            self.values = values

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Column', '::omero::grid::DatasetColumn')

        def ice_id(self, current=None):
            return '::omero::grid::DatasetColumn'

        def ice_staticId():
            return '::omero::grid::DatasetColumn'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_DatasetColumn)

        __repr__ = __str__

    _M_omero.grid.DatasetColumnPrx = Ice.createTempClass()
    class DatasetColumnPrx(_M_omero.grid.ColumnPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.DatasetColumnPrx.ice_checkedCast(proxy, '::omero::grid::DatasetColumn', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.DatasetColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::DatasetColumn'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_DatasetColumnPrx = IcePy.defineProxy('::omero::grid::DatasetColumn', DatasetColumnPrx)

    _M_omero.grid._t_DatasetColumn = IcePy.defineClass('::omero::grid::DatasetColumn', DatasetColumn, -1, (), False, False, _M_omero.grid._t_Column, (), (('values', (), _M_omero.api._t_LongArray, False, 0),))
    DatasetColumn._ice_type = _M_omero.grid._t_DatasetColumn

    _M_omero.grid.DatasetColumn = DatasetColumn
    del DatasetColumn

    _M_omero.grid.DatasetColumnPrx = DatasetColumnPrx
    del DatasetColumnPrx

if 'RoiColumn' not in _M_omero.grid.__dict__:
    _M_omero.grid.RoiColumn = Ice.createTempClass()
    class RoiColumn(_M_omero.grid.Column):
        def __init__(self, name='', description='', values=None):
            _M_omero.grid.Column.__init__(self, name, description)
            self.values = values

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Column', '::omero::grid::RoiColumn')

        def ice_id(self, current=None):
            return '::omero::grid::RoiColumn'

        def ice_staticId():
            return '::omero::grid::RoiColumn'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_RoiColumn)

        __repr__ = __str__

    _M_omero.grid.RoiColumnPrx = Ice.createTempClass()
    class RoiColumnPrx(_M_omero.grid.ColumnPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.RoiColumnPrx.ice_checkedCast(proxy, '::omero::grid::RoiColumn', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.RoiColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::RoiColumn'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_RoiColumnPrx = IcePy.defineProxy('::omero::grid::RoiColumn', RoiColumnPrx)

    _M_omero.grid._t_RoiColumn = IcePy.defineClass('::omero::grid::RoiColumn', RoiColumn, -1, (), False, False, _M_omero.grid._t_Column, (), (('values', (), _M_omero.api._t_LongArray, False, 0),))
    RoiColumn._ice_type = _M_omero.grid._t_RoiColumn

    _M_omero.grid.RoiColumn = RoiColumn
    del RoiColumn

    _M_omero.grid.RoiColumnPrx = RoiColumnPrx
    del RoiColumnPrx

if 'WellColumn' not in _M_omero.grid.__dict__:
    _M_omero.grid.WellColumn = Ice.createTempClass()
    class WellColumn(_M_omero.grid.Column):
        def __init__(self, name='', description='', values=None):
            _M_omero.grid.Column.__init__(self, name, description)
            self.values = values

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Column', '::omero::grid::WellColumn')

        def ice_id(self, current=None):
            return '::omero::grid::WellColumn'

        def ice_staticId():
            return '::omero::grid::WellColumn'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_WellColumn)

        __repr__ = __str__

    _M_omero.grid.WellColumnPrx = Ice.createTempClass()
    class WellColumnPrx(_M_omero.grid.ColumnPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.WellColumnPrx.ice_checkedCast(proxy, '::omero::grid::WellColumn', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.WellColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::WellColumn'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_WellColumnPrx = IcePy.defineProxy('::omero::grid::WellColumn', WellColumnPrx)

    _M_omero.grid._t_WellColumn = IcePy.defineClass('::omero::grid::WellColumn', WellColumn, -1, (), False, False, _M_omero.grid._t_Column, (), (('values', (), _M_omero.api._t_LongArray, False, 0),))
    WellColumn._ice_type = _M_omero.grid._t_WellColumn

    _M_omero.grid.WellColumn = WellColumn
    del WellColumn

    _M_omero.grid.WellColumnPrx = WellColumnPrx
    del WellColumnPrx

if 'PlateColumn' not in _M_omero.grid.__dict__:
    _M_omero.grid.PlateColumn = Ice.createTempClass()
    class PlateColumn(_M_omero.grid.Column):
        def __init__(self, name='', description='', values=None):
            _M_omero.grid.Column.__init__(self, name, description)
            self.values = values

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Column', '::omero::grid::PlateColumn')

        def ice_id(self, current=None):
            return '::omero::grid::PlateColumn'

        def ice_staticId():
            return '::omero::grid::PlateColumn'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_PlateColumn)

        __repr__ = __str__

    _M_omero.grid.PlateColumnPrx = Ice.createTempClass()
    class PlateColumnPrx(_M_omero.grid.ColumnPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.PlateColumnPrx.ice_checkedCast(proxy, '::omero::grid::PlateColumn', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.PlateColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::PlateColumn'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_PlateColumnPrx = IcePy.defineProxy('::omero::grid::PlateColumn', PlateColumnPrx)

    _M_omero.grid._t_PlateColumn = IcePy.defineClass('::omero::grid::PlateColumn', PlateColumn, -1, (), False, False, _M_omero.grid._t_Column, (), (('values', (), _M_omero.api._t_LongArray, False, 0),))
    PlateColumn._ice_type = _M_omero.grid._t_PlateColumn

    _M_omero.grid.PlateColumn = PlateColumn
    del PlateColumn

    _M_omero.grid.PlateColumnPrx = PlateColumnPrx
    del PlateColumnPrx

if 'BoolColumn' not in _M_omero.grid.__dict__:
    _M_omero.grid.BoolColumn = Ice.createTempClass()
    class BoolColumn(_M_omero.grid.Column):
        def __init__(self, name='', description='', values=None):
            _M_omero.grid.Column.__init__(self, name, description)
            self.values = values

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::BoolColumn', '::omero::grid::Column')

        def ice_id(self, current=None):
            return '::omero::grid::BoolColumn'

        def ice_staticId():
            return '::omero::grid::BoolColumn'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_BoolColumn)

        __repr__ = __str__

    _M_omero.grid.BoolColumnPrx = Ice.createTempClass()
    class BoolColumnPrx(_M_omero.grid.ColumnPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.BoolColumnPrx.ice_checkedCast(proxy, '::omero::grid::BoolColumn', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.BoolColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::BoolColumn'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_BoolColumnPrx = IcePy.defineProxy('::omero::grid::BoolColumn', BoolColumnPrx)

    _M_omero.grid._t_BoolColumn = IcePy.defineClass('::omero::grid::BoolColumn', BoolColumn, -1, (), False, False, _M_omero.grid._t_Column, (), (('values', (), _M_omero.api._t_BoolArray, False, 0),))
    BoolColumn._ice_type = _M_omero.grid._t_BoolColumn

    _M_omero.grid.BoolColumn = BoolColumn
    del BoolColumn

    _M_omero.grid.BoolColumnPrx = BoolColumnPrx
    del BoolColumnPrx

if 'DoubleColumn' not in _M_omero.grid.__dict__:
    _M_omero.grid.DoubleColumn = Ice.createTempClass()
    class DoubleColumn(_M_omero.grid.Column):
        def __init__(self, name='', description='', values=None):
            _M_omero.grid.Column.__init__(self, name, description)
            self.values = values

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Column', '::omero::grid::DoubleColumn')

        def ice_id(self, current=None):
            return '::omero::grid::DoubleColumn'

        def ice_staticId():
            return '::omero::grid::DoubleColumn'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_DoubleColumn)

        __repr__ = __str__

    _M_omero.grid.DoubleColumnPrx = Ice.createTempClass()
    class DoubleColumnPrx(_M_omero.grid.ColumnPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.DoubleColumnPrx.ice_checkedCast(proxy, '::omero::grid::DoubleColumn', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.DoubleColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::DoubleColumn'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_DoubleColumnPrx = IcePy.defineProxy('::omero::grid::DoubleColumn', DoubleColumnPrx)

    _M_omero.grid._t_DoubleColumn = IcePy.defineClass('::omero::grid::DoubleColumn', DoubleColumn, -1, (), False, False, _M_omero.grid._t_Column, (), (('values', (), _M_omero.api._t_DoubleArray, False, 0),))
    DoubleColumn._ice_type = _M_omero.grid._t_DoubleColumn

    _M_omero.grid.DoubleColumn = DoubleColumn
    del DoubleColumn

    _M_omero.grid.DoubleColumnPrx = DoubleColumnPrx
    del DoubleColumnPrx

if 'LongColumn' not in _M_omero.grid.__dict__:
    _M_omero.grid.LongColumn = Ice.createTempClass()
    class LongColumn(_M_omero.grid.Column):
        def __init__(self, name='', description='', values=None):
            _M_omero.grid.Column.__init__(self, name, description)
            self.values = values

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Column', '::omero::grid::LongColumn')

        def ice_id(self, current=None):
            return '::omero::grid::LongColumn'

        def ice_staticId():
            return '::omero::grid::LongColumn'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_LongColumn)

        __repr__ = __str__

    _M_omero.grid.LongColumnPrx = Ice.createTempClass()
    class LongColumnPrx(_M_omero.grid.ColumnPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.LongColumnPrx.ice_checkedCast(proxy, '::omero::grid::LongColumn', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.LongColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::LongColumn'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_LongColumnPrx = IcePy.defineProxy('::omero::grid::LongColumn', LongColumnPrx)

    _M_omero.grid._t_LongColumn = IcePy.defineClass('::omero::grid::LongColumn', LongColumn, -1, (), False, False, _M_omero.grid._t_Column, (), (('values', (), _M_omero.api._t_LongArray, False, 0),))
    LongColumn._ice_type = _M_omero.grid._t_LongColumn

    _M_omero.grid.LongColumn = LongColumn
    del LongColumn

    _M_omero.grid.LongColumnPrx = LongColumnPrx
    del LongColumnPrx

if 'StringColumn' not in _M_omero.grid.__dict__:
    _M_omero.grid.StringColumn = Ice.createTempClass()
    class StringColumn(_M_omero.grid.Column):
        def __init__(self, name='', description='', size=0, values=None):
            _M_omero.grid.Column.__init__(self, name, description)
            self.size = size
            self.values = values

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Column', '::omero::grid::StringColumn')

        def ice_id(self, current=None):
            return '::omero::grid::StringColumn'

        def ice_staticId():
            return '::omero::grid::StringColumn'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_StringColumn)

        __repr__ = __str__

    _M_omero.grid.StringColumnPrx = Ice.createTempClass()
    class StringColumnPrx(_M_omero.grid.ColumnPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.StringColumnPrx.ice_checkedCast(proxy, '::omero::grid::StringColumn', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.StringColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::StringColumn'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_StringColumnPrx = IcePy.defineProxy('::omero::grid::StringColumn', StringColumnPrx)

    _M_omero.grid._t_StringColumn = IcePy.defineClass('::omero::grid::StringColumn', StringColumn, -1, (), False, False, _M_omero.grid._t_Column, (), (
        ('size', (), IcePy._t_long, False, 0),
        ('values', (), _M_omero.api._t_StringArray, False, 0)
    ))
    StringColumn._ice_type = _M_omero.grid._t_StringColumn

    _M_omero.grid.StringColumn = StringColumn
    del StringColumn

    _M_omero.grid.StringColumnPrx = StringColumnPrx
    del StringColumnPrx

if 'FloatArrayColumn' not in _M_omero.grid.__dict__:
    _M_omero.grid.FloatArrayColumn = Ice.createTempClass()
    class FloatArrayColumn(_M_omero.grid.Column):
        def __init__(self, name='', description='', size=0, values=None):
            _M_omero.grid.Column.__init__(self, name, description)
            self.size = size
            self.values = values

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Column', '::omero::grid::FloatArrayColumn')

        def ice_id(self, current=None):
            return '::omero::grid::FloatArrayColumn'

        def ice_staticId():
            return '::omero::grid::FloatArrayColumn'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_FloatArrayColumn)

        __repr__ = __str__

    _M_omero.grid.FloatArrayColumnPrx = Ice.createTempClass()
    class FloatArrayColumnPrx(_M_omero.grid.ColumnPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.FloatArrayColumnPrx.ice_checkedCast(proxy, '::omero::grid::FloatArrayColumn', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.FloatArrayColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::FloatArrayColumn'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_FloatArrayColumnPrx = IcePy.defineProxy('::omero::grid::FloatArrayColumn', FloatArrayColumnPrx)

    _M_omero.grid._t_FloatArrayColumn = IcePy.defineClass('::omero::grid::FloatArrayColumn', FloatArrayColumn, -1, (), False, False, _M_omero.grid._t_Column, (), (
        ('size', (), IcePy._t_long, False, 0),
        ('values', (), _M_omero.api._t_FloatArrayArray, False, 0)
    ))
    FloatArrayColumn._ice_type = _M_omero.grid._t_FloatArrayColumn

    _M_omero.grid.FloatArrayColumn = FloatArrayColumn
    del FloatArrayColumn

    _M_omero.grid.FloatArrayColumnPrx = FloatArrayColumnPrx
    del FloatArrayColumnPrx

if 'DoubleArrayColumn' not in _M_omero.grid.__dict__:
    _M_omero.grid.DoubleArrayColumn = Ice.createTempClass()
    class DoubleArrayColumn(_M_omero.grid.Column):
        def __init__(self, name='', description='', size=0, values=None):
            _M_omero.grid.Column.__init__(self, name, description)
            self.size = size
            self.values = values

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Column', '::omero::grid::DoubleArrayColumn')

        def ice_id(self, current=None):
            return '::omero::grid::DoubleArrayColumn'

        def ice_staticId():
            return '::omero::grid::DoubleArrayColumn'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_DoubleArrayColumn)

        __repr__ = __str__

    _M_omero.grid.DoubleArrayColumnPrx = Ice.createTempClass()
    class DoubleArrayColumnPrx(_M_omero.grid.ColumnPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.DoubleArrayColumnPrx.ice_checkedCast(proxy, '::omero::grid::DoubleArrayColumn', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.DoubleArrayColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::DoubleArrayColumn'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_DoubleArrayColumnPrx = IcePy.defineProxy('::omero::grid::DoubleArrayColumn', DoubleArrayColumnPrx)

    _M_omero.grid._t_DoubleArrayColumn = IcePy.defineClass('::omero::grid::DoubleArrayColumn', DoubleArrayColumn, -1, (), False, False, _M_omero.grid._t_Column, (), (
        ('size', (), IcePy._t_long, False, 0),
        ('values', (), _M_omero.api._t_DoubleArrayArray, False, 0)
    ))
    DoubleArrayColumn._ice_type = _M_omero.grid._t_DoubleArrayColumn

    _M_omero.grid.DoubleArrayColumn = DoubleArrayColumn
    del DoubleArrayColumn

    _M_omero.grid.DoubleArrayColumnPrx = DoubleArrayColumnPrx
    del DoubleArrayColumnPrx

if 'LongArrayColumn' not in _M_omero.grid.__dict__:
    _M_omero.grid.LongArrayColumn = Ice.createTempClass()
    class LongArrayColumn(_M_omero.grid.Column):
        def __init__(self, name='', description='', size=0, values=None):
            _M_omero.grid.Column.__init__(self, name, description)
            self.size = size
            self.values = values

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Column', '::omero::grid::LongArrayColumn')

        def ice_id(self, current=None):
            return '::omero::grid::LongArrayColumn'

        def ice_staticId():
            return '::omero::grid::LongArrayColumn'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_LongArrayColumn)

        __repr__ = __str__

    _M_omero.grid.LongArrayColumnPrx = Ice.createTempClass()
    class LongArrayColumnPrx(_M_omero.grid.ColumnPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.LongArrayColumnPrx.ice_checkedCast(proxy, '::omero::grid::LongArrayColumn', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.LongArrayColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::LongArrayColumn'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_LongArrayColumnPrx = IcePy.defineProxy('::omero::grid::LongArrayColumn', LongArrayColumnPrx)

    _M_omero.grid._t_LongArrayColumn = IcePy.defineClass('::omero::grid::LongArrayColumn', LongArrayColumn, -1, (), False, False, _M_omero.grid._t_Column, (), (
        ('size', (), IcePy._t_long, False, 0),
        ('values', (), _M_omero.api._t_LongArrayArray, False, 0)
    ))
    LongArrayColumn._ice_type = _M_omero.grid._t_LongArrayColumn

    _M_omero.grid.LongArrayColumn = LongArrayColumn
    del LongArrayColumn

    _M_omero.grid.LongArrayColumnPrx = LongArrayColumnPrx
    del LongArrayColumnPrx

if 'MaskColumn' not in _M_omero.grid.__dict__:
    _M_omero.grid.MaskColumn = Ice.createTempClass()
    class MaskColumn(_M_omero.grid.Column):
        """
        Column requiring special handling.
        """
        def __init__(self, name='', description='', imageId=None, theZ=None, theT=None, x=None, y=None, w=None, h=None, bytes=None):
            _M_omero.grid.Column.__init__(self, name, description)
            self.imageId = imageId
            self.theZ = theZ
            self.theT = theT
            self.x = x
            self.y = y
            self.w = w
            self.h = h
            self.bytes = bytes

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Column', '::omero::grid::MaskColumn')

        def ice_id(self, current=None):
            return '::omero::grid::MaskColumn'

        def ice_staticId():
            return '::omero::grid::MaskColumn'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_MaskColumn)

        __repr__ = __str__

    _M_omero.grid.MaskColumnPrx = Ice.createTempClass()
    class MaskColumnPrx(_M_omero.grid.ColumnPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.MaskColumnPrx.ice_checkedCast(proxy, '::omero::grid::MaskColumn', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.MaskColumnPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::MaskColumn'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_MaskColumnPrx = IcePy.defineProxy('::omero::grid::MaskColumn', MaskColumnPrx)

    _M_omero.grid._t_MaskColumn = IcePy.defineClass('::omero::grid::MaskColumn', MaskColumn, -1, (), False, False, _M_omero.grid._t_Column, (), (
        ('imageId', (), _M_omero.api._t_LongArray, False, 0),
        ('theZ', (), _M_omero.api._t_IntegerArray, False, 0),
        ('theT', (), _M_omero.api._t_IntegerArray, False, 0),
        ('x', (), _M_omero.api._t_DoubleArray, False, 0),
        ('y', (), _M_omero.api._t_DoubleArray, False, 0),
        ('w', (), _M_omero.api._t_DoubleArray, False, 0),
        ('h', (), _M_omero.api._t_DoubleArray, False, 0),
        ('bytes', (), _M_omero.api._t_ByteArrayArray, False, 0)
    ))
    MaskColumn._ice_type = _M_omero.grid._t_MaskColumn

    _M_omero.grid.MaskColumn = MaskColumn
    del MaskColumn

    _M_omero.grid.MaskColumnPrx = MaskColumnPrx
    del MaskColumnPrx

if '_t_ColumnArray' not in _M_omero.grid.__dict__:
    _M_omero.grid._t_ColumnArray = IcePy.defineSequence('::omero::grid::ColumnArray', (), _M_omero.grid._t_Column)

if 'Data' not in _M_omero.grid.__dict__:
    _M_omero.grid.Data = Ice.createTempClass()
    class Data(Ice.Object):
        def __init__(self, lastModification=0, rowNumbers=None, columns=None):
            self.lastModification = lastModification
            self.rowNumbers = rowNumbers
            self.columns = columns

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Data')

        def ice_id(self, current=None):
            return '::omero::grid::Data'

        def ice_staticId():
            return '::omero::grid::Data'
        ice_staticId = staticmethod(ice_staticId)

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_Data)

        __repr__ = __str__

    _M_omero.grid.DataPrx = Ice.createTempClass()
    class DataPrx(Ice.ObjectPrx):

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.DataPrx.ice_checkedCast(proxy, '::omero::grid::Data', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.DataPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::Data'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_DataPrx = IcePy.defineProxy('::omero::grid::Data', DataPrx)

    _M_omero.grid._t_Data = IcePy.declareClass('::omero::grid::Data')

    _M_omero.grid._t_Data = IcePy.defineClass('::omero::grid::Data', Data, -1, (), False, False, None, (), (
        ('lastModification', (), IcePy._t_long, False, 0),
        ('rowNumbers', (), _M_omero.api._t_LongArray, False, 0),
        ('columns', (), _M_omero.grid._t_ColumnArray, False, 0)
    ))
    Data._ice_type = _M_omero.grid._t_Data

    _M_omero.grid.Data = Data
    del Data

    _M_omero.grid.DataPrx = DataPrx
    del DataPrx

if 'Table' not in _M_omero.grid.__dict__:
    _M_omero.grid.Table = Ice.createTempClass()
    class Table(Ice.Object):
        def __init__(self):
            if Ice.getType(self) == _M_omero.grid.Table:
                raise RuntimeError('omero.grid.Table is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Table')

        def ice_id(self, current=None):
            return '::omero::grid::Table'

        def ice_staticId():
            return '::omero::grid::Table'
        ice_staticId = staticmethod(ice_staticId)

        def getOriginalFile(self, current=None):
            pass

        def getHeaders(self, current=None):
            """
            Returns empty columns.
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def getNumberOfRows(self, current=None):
            pass

        def getWhereList(self, condition, variables, start, stop, step, current=None):
            """
            http://www.pytables.org/docs/manual/apb.html
            Leave all three of start, stop, step to 0 to disable.
            TODO:Test effect of returning a billion rows matching getWhereList()
            Arguments:
            condition -- 
            variables -- 
            start -- 
            stop -- 
            step -- 
            current -- The Current object for the invocation.
            """
            pass

        def readCoordinates(self, rowNumbers, current=None):
            """
            Read the given rows of data.
            Arguments:
            rowNumbers -- must contain at least one element or an omero.ApiUsageException will be thrown.
            current -- The Current object for the invocation.
            """
            pass

        def read(self, colNumbers, start, stop, current=None):
            """
            http://www.pytables.org/docs/manual/ch04.html#Table.read
            Arguments:
            colNumbers -- 
            start -- 
            stop -- 
            current -- The Current object for the invocation.
            """
            pass

        def slice(self, colNumbers, rowNumbers, current=None):
            """
            Simple slice method which will return only the given columns
            and rows in the order supplied.
            If colNumbers or rowNumbers is empty (or None), then all values
            will be returned.
            Python examples:
            data = table.slice(None, None)
            assert len(data.rowNumbers) == table.getNumberOfRows()
            data = table.slice(None, \[3,2,1])
            assert data.rowNumbers == \[3,2,1]
            Arguments:
            colNumbers -- 
            rowNumbers -- 
            current -- The Current object for the invocation.
            """
            pass

        def addData(self, cols, current=None):
            pass

        def update(self, modifiedData, current=None):
            """
            Allows the user to modify a Data instance passed back
            from a query method and have the values modified. It
            is critical that the {@code Data.lastModification} and the
            {@code Data.rowNumbers} fields are properly set. An exception
            will be thrown if the data has since been modified.
            Arguments:
            modifiedData -- 
            current -- The Current object for the invocation.
            """
            pass

        def getAllMetadata(self, current=None):
            pass

        def getMetadata(self, key, current=None):
            pass

        def setAllMetadata(self, dict, current=None):
            pass

        def setMetadata(self, key, value, current=None):
            pass

        def initialize(self, cols, current=None):
            """
            Initializes the structure based on
            Arguments:
            cols -- 
            current -- The Current object for the invocation.
            """
            pass

        def addColumn(self, col, current=None):
            """
            Adds a column and returns the position index of the new column.
            Arguments:
            col -- 
            current -- The Current object for the invocation.
            """
            pass

        def delete(self, current=None):
            pass

        def close(self, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_Table)

        __repr__ = __str__

    _M_omero.grid.TablePrx = Ice.createTempClass()
    class TablePrx(Ice.ObjectPrx):

        def getOriginalFile(self, _ctx=None):
            return _M_omero.grid.Table._op_getOriginalFile.invoke(self, ((), _ctx))

        def begin_getOriginalFile(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_getOriginalFile.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getOriginalFile(self, _r):
            return _M_omero.grid.Table._op_getOriginalFile.end(self, _r)

        """
        Returns empty columns.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def getHeaders(self, _ctx=None):
            return _M_omero.grid.Table._op_getHeaders.invoke(self, ((), _ctx))

        """
        Returns empty columns.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getHeaders(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_getHeaders.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Returns empty columns.
        Arguments:
        """
        def end_getHeaders(self, _r):
            return _M_omero.grid.Table._op_getHeaders.end(self, _r)

        def getNumberOfRows(self, _ctx=None):
            return _M_omero.grid.Table._op_getNumberOfRows.invoke(self, ((), _ctx))

        def begin_getNumberOfRows(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_getNumberOfRows.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getNumberOfRows(self, _r):
            return _M_omero.grid.Table._op_getNumberOfRows.end(self, _r)

        """
        http://www.pytables.org/docs/manual/apb.html
        Leave all three of start, stop, step to 0 to disable.
        TODO:Test effect of returning a billion rows matching getWhereList()
        Arguments:
        condition -- 
        variables -- 
        start -- 
        stop -- 
        step -- 
        _ctx -- The request context for the invocation.
        """
        def getWhereList(self, condition, variables, start, stop, step, _ctx=None):
            return _M_omero.grid.Table._op_getWhereList.invoke(self, ((condition, variables, start, stop, step), _ctx))

        """
        http://www.pytables.org/docs/manual/apb.html
        Leave all three of start, stop, step to 0 to disable.
        TODO:Test effect of returning a billion rows matching getWhereList()
        Arguments:
        condition -- 
        variables -- 
        start -- 
        stop -- 
        step -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getWhereList(self, condition, variables, start, stop, step, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_getWhereList.begin(self, ((condition, variables, start, stop, step), _response, _ex, _sent, _ctx))

        """
        http://www.pytables.org/docs/manual/apb.html
        Leave all three of start, stop, step to 0 to disable.
        TODO:Test effect of returning a billion rows matching getWhereList()
        Arguments:
        condition -- 
        variables -- 
        start -- 
        stop -- 
        step -- 
        """
        def end_getWhereList(self, _r):
            return _M_omero.grid.Table._op_getWhereList.end(self, _r)

        """
        Read the given rows of data.
        Arguments:
        rowNumbers -- must contain at least one element or an omero.ApiUsageException will be thrown.
        _ctx -- The request context for the invocation.
        """
        def readCoordinates(self, rowNumbers, _ctx=None):
            return _M_omero.grid.Table._op_readCoordinates.invoke(self, ((rowNumbers, ), _ctx))

        """
        Read the given rows of data.
        Arguments:
        rowNumbers -- must contain at least one element or an omero.ApiUsageException will be thrown.
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_readCoordinates(self, rowNumbers, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_readCoordinates.begin(self, ((rowNumbers, ), _response, _ex, _sent, _ctx))

        """
        Read the given rows of data.
        Arguments:
        rowNumbers -- must contain at least one element or an omero.ApiUsageException will be thrown.
        """
        def end_readCoordinates(self, _r):
            return _M_omero.grid.Table._op_readCoordinates.end(self, _r)

        """
        http://www.pytables.org/docs/manual/ch04.html#Table.read
        Arguments:
        colNumbers -- 
        start -- 
        stop -- 
        _ctx -- The request context for the invocation.
        """
        def read(self, colNumbers, start, stop, _ctx=None):
            return _M_omero.grid.Table._op_read.invoke(self, ((colNumbers, start, stop), _ctx))

        """
        http://www.pytables.org/docs/manual/ch04.html#Table.read
        Arguments:
        colNumbers -- 
        start -- 
        stop -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_read(self, colNumbers, start, stop, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_read.begin(self, ((colNumbers, start, stop), _response, _ex, _sent, _ctx))

        """
        http://www.pytables.org/docs/manual/ch04.html#Table.read
        Arguments:
        colNumbers -- 
        start -- 
        stop -- 
        """
        def end_read(self, _r):
            return _M_omero.grid.Table._op_read.end(self, _r)

        """
        Simple slice method which will return only the given columns
        and rows in the order supplied.
        If colNumbers or rowNumbers is empty (or None), then all values
        will be returned.
        Python examples:
        data = table.slice(None, None)
        assert len(data.rowNumbers) == table.getNumberOfRows()
        data = table.slice(None, \[3,2,1])
        assert data.rowNumbers == \[3,2,1]
        Arguments:
        colNumbers -- 
        rowNumbers -- 
        _ctx -- The request context for the invocation.
        """
        def slice(self, colNumbers, rowNumbers, _ctx=None):
            return _M_omero.grid.Table._op_slice.invoke(self, ((colNumbers, rowNumbers), _ctx))

        """
        Simple slice method which will return only the given columns
        and rows in the order supplied.
        If colNumbers or rowNumbers is empty (or None), then all values
        will be returned.
        Python examples:
        data = table.slice(None, None)
        assert len(data.rowNumbers) == table.getNumberOfRows()
        data = table.slice(None, \[3,2,1])
        assert data.rowNumbers == \[3,2,1]
        Arguments:
        colNumbers -- 
        rowNumbers -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_slice(self, colNumbers, rowNumbers, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_slice.begin(self, ((colNumbers, rowNumbers), _response, _ex, _sent, _ctx))

        """
        Simple slice method which will return only the given columns
        and rows in the order supplied.
        If colNumbers or rowNumbers is empty (or None), then all values
        will be returned.
        Python examples:
        data = table.slice(None, None)
        assert len(data.rowNumbers) == table.getNumberOfRows()
        data = table.slice(None, \[3,2,1])
        assert data.rowNumbers == \[3,2,1]
        Arguments:
        colNumbers -- 
        rowNumbers -- 
        """
        def end_slice(self, _r):
            return _M_omero.grid.Table._op_slice.end(self, _r)

        def addData(self, cols, _ctx=None):
            return _M_omero.grid.Table._op_addData.invoke(self, ((cols, ), _ctx))

        def begin_addData(self, cols, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_addData.begin(self, ((cols, ), _response, _ex, _sent, _ctx))

        def end_addData(self, _r):
            return _M_omero.grid.Table._op_addData.end(self, _r)

        """
        Allows the user to modify a Data instance passed back
        from a query method and have the values modified. It
        is critical that the {@code Data.lastModification} and the
        {@code Data.rowNumbers} fields are properly set. An exception
        will be thrown if the data has since been modified.
        Arguments:
        modifiedData -- 
        _ctx -- The request context for the invocation.
        """
        def update(self, modifiedData, _ctx=None):
            return _M_omero.grid.Table._op_update.invoke(self, ((modifiedData, ), _ctx))

        """
        Allows the user to modify a Data instance passed back
        from a query method and have the values modified. It
        is critical that the {@code Data.lastModification} and the
        {@code Data.rowNumbers} fields are properly set. An exception
        will be thrown if the data has since been modified.
        Arguments:
        modifiedData -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_update(self, modifiedData, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_update.begin(self, ((modifiedData, ), _response, _ex, _sent, _ctx))

        """
        Allows the user to modify a Data instance passed back
        from a query method and have the values modified. It
        is critical that the {@code Data.lastModification} and the
        {@code Data.rowNumbers} fields are properly set. An exception
        will be thrown if the data has since been modified.
        Arguments:
        modifiedData -- 
        """
        def end_update(self, _r):
            return _M_omero.grid.Table._op_update.end(self, _r)

        def getAllMetadata(self, _ctx=None):
            return _M_omero.grid.Table._op_getAllMetadata.invoke(self, ((), _ctx))

        def begin_getAllMetadata(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_getAllMetadata.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAllMetadata(self, _r):
            return _M_omero.grid.Table._op_getAllMetadata.end(self, _r)

        def getMetadata(self, key, _ctx=None):
            return _M_omero.grid.Table._op_getMetadata.invoke(self, ((key, ), _ctx))

        def begin_getMetadata(self, key, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_getMetadata.begin(self, ((key, ), _response, _ex, _sent, _ctx))

        def end_getMetadata(self, _r):
            return _M_omero.grid.Table._op_getMetadata.end(self, _r)

        def setAllMetadata(self, dict, _ctx=None):
            return _M_omero.grid.Table._op_setAllMetadata.invoke(self, ((dict, ), _ctx))

        def begin_setAllMetadata(self, dict, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_setAllMetadata.begin(self, ((dict, ), _response, _ex, _sent, _ctx))

        def end_setAllMetadata(self, _r):
            return _M_omero.grid.Table._op_setAllMetadata.end(self, _r)

        def setMetadata(self, key, value, _ctx=None):
            return _M_omero.grid.Table._op_setMetadata.invoke(self, ((key, value), _ctx))

        def begin_setMetadata(self, key, value, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_setMetadata.begin(self, ((key, value), _response, _ex, _sent, _ctx))

        def end_setMetadata(self, _r):
            return _M_omero.grid.Table._op_setMetadata.end(self, _r)

        """
        Initializes the structure based on
        Arguments:
        cols -- 
        _ctx -- The request context for the invocation.
        """
        def initialize(self, cols, _ctx=None):
            return _M_omero.grid.Table._op_initialize.invoke(self, ((cols, ), _ctx))

        """
        Initializes the structure based on
        Arguments:
        cols -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_initialize(self, cols, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_initialize.begin(self, ((cols, ), _response, _ex, _sent, _ctx))

        """
        Initializes the structure based on
        Arguments:
        cols -- 
        """
        def end_initialize(self, _r):
            return _M_omero.grid.Table._op_initialize.end(self, _r)

        """
        Adds a column and returns the position index of the new column.
        Arguments:
        col -- 
        _ctx -- The request context for the invocation.
        """
        def addColumn(self, col, _ctx=None):
            return _M_omero.grid.Table._op_addColumn.invoke(self, ((col, ), _ctx))

        """
        Adds a column and returns the position index of the new column.
        Arguments:
        col -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_addColumn(self, col, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_addColumn.begin(self, ((col, ), _response, _ex, _sent, _ctx))

        """
        Adds a column and returns the position index of the new column.
        Arguments:
        col -- 
        """
        def end_addColumn(self, _r):
            return _M_omero.grid.Table._op_addColumn.end(self, _r)

        def delete(self, _ctx=None):
            return _M_omero.grid.Table._op_delete.invoke(self, ((), _ctx))

        def begin_delete(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_delete.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_delete(self, _r):
            return _M_omero.grid.Table._op_delete.end(self, _r)

        def close(self, _ctx=None):
            return _M_omero.grid.Table._op_close.invoke(self, ((), _ctx))

        def begin_close(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Table._op_close.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_close(self, _r):
            return _M_omero.grid.Table._op_close.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.TablePrx.ice_checkedCast(proxy, '::omero::grid::Table', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.TablePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::Table'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_TablePrx = IcePy.defineProxy('::omero::grid::Table', TablePrx)

    _M_omero.grid._t_Table = IcePy.defineClass('::omero::grid::Table', Table, -1, (), True, False, None, (), ())
    Table._ice_type = _M_omero.grid._t_Table

    Table._op_getOriginalFile = IcePy.Operation('getOriginalFile', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (), (), ((), _M_omero.model._t_OriginalFile, False, 0), (_M_omero._t_ServerError,))
    Table._op_getHeaders = IcePy.Operation('getHeaders', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (), (), ((), _M_omero.grid._t_ColumnArray, False, 0), (_M_omero._t_ServerError,))
    Table._op_getNumberOfRows = IcePy.Operation('getNumberOfRows', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (), (), ((), IcePy._t_long, False, 0), (_M_omero._t_ServerError,))
    Table._op_getWhereList = IcePy.Operation('getWhereList', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), IcePy._t_string, False, 0), ((), _M_omero._t_RTypeDict, False, 0), ((), IcePy._t_long, False, 0), ((), IcePy._t_long, False, 0), ((), IcePy._t_long, False, 0)), (), ((), _M_omero.api._t_LongArray, False, 0), (_M_omero._t_ServerError,))
    Table._op_readCoordinates = IcePy.Operation('readCoordinates', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), _M_omero.api._t_LongArray, False, 0),), (), ((), _M_omero.grid._t_Data, False, 0), (_M_omero._t_ServerError,))
    Table._op_read = IcePy.Operation('read', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), _M_omero.api._t_LongArray, False, 0), ((), IcePy._t_long, False, 0), ((), IcePy._t_long, False, 0)), (), ((), _M_omero.grid._t_Data, False, 0), (_M_omero._t_ServerError,))
    Table._op_slice = IcePy.Operation('slice', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), _M_omero.api._t_LongArray, False, 0), ((), _M_omero.api._t_LongArray, False, 0)), (), ((), _M_omero.grid._t_Data, False, 0), (_M_omero._t_ServerError,))
    Table._op_addData = IcePy.Operation('addData', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.grid._t_ColumnArray, False, 0),), (), None, (_M_omero._t_ServerError,))
    Table._op_update = IcePy.Operation('update', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.grid._t_Data, False, 0),), (), None, (_M_omero._t_ServerError,))
    Table._op_getAllMetadata = IcePy.Operation('getAllMetadata', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (), (), ((), _M_omero._t_RTypeDict, False, 0), (_M_omero._t_ServerError,))
    Table._op_getMetadata = IcePy.Operation('getMetadata', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), IcePy._t_string, False, 0),), (), ((), _M_omero._t_RType, False, 0), (_M_omero._t_ServerError,))
    Table._op_setAllMetadata = IcePy.Operation('setAllMetadata', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), _M_omero._t_RTypeDict, False, 0),), (), None, (_M_omero._t_ServerError,))
    Table._op_setMetadata = IcePy.Operation('setMetadata', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), IcePy._t_string, False, 0), ((), _M_omero._t_RType, False, 0)), (), None, (_M_omero._t_ServerError,))
    Table._op_initialize = IcePy.Operation('initialize', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.grid._t_ColumnArray, False, 0),), (), None, (_M_omero._t_ServerError,))
    Table._op_addColumn = IcePy.Operation('addColumn', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.grid._t_Column, False, 0),), (), ((), IcePy._t_int, False, 0), (_M_omero._t_ServerError,))
    Table._op_delete = IcePy.Operation('delete', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, (_M_omero._t_ServerError,))
    Table._op_close = IcePy.Operation('close', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, (_M_omero._t_ServerError,))

    _M_omero.grid.Table = Table
    del Table

    _M_omero.grid.TablePrx = TablePrx
    del TablePrx

if 'Tables' not in _M_omero.grid.__dict__:
    _M_omero.grid.Tables = Ice.createTempClass()
    class Tables(Ice.Object):
        def __init__(self):
            if Ice.getType(self) == _M_omero.grid.Tables:
                raise RuntimeError('omero.grid.Tables is an abstract class')

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::grid::Tables')

        def ice_id(self, current=None):
            return '::omero::grid::Tables'

        def ice_staticId():
            return '::omero::grid::Tables'
        ice_staticId = staticmethod(ice_staticId)

        def getRepository(self, current=None):
            """
            Returns the Repository which this Tables service is watching.
            Arguments:
            current -- The Current object for the invocation.
            """
            pass

        def getTable(self, file, sf, current=None):
            """
            Returns the Table service for the given ""OMERO.tables"" file.
            This service will open the file locally to access the data.
            After any modification, the file will be saved locally and
            the server asked to update the database record. This is done
            via services in the omero.api.ServiceFactory.
            Arguments:
            file -- 
            sf -- 
            current -- The Current object for the invocation.
            """
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.grid._t_Tables)

        __repr__ = __str__

    _M_omero.grid.TablesPrx = Ice.createTempClass()
    class TablesPrx(Ice.ObjectPrx):

        """
        Returns the Repository which this Tables service is watching.
        Arguments:
        _ctx -- The request context for the invocation.
        """
        def getRepository(self, _ctx=None):
            return _M_omero.grid.Tables._op_getRepository.invoke(self, ((), _ctx))

        """
        Returns the Repository which this Tables service is watching.
        Arguments:
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getRepository(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Tables._op_getRepository.begin(self, ((), _response, _ex, _sent, _ctx))

        """
        Returns the Repository which this Tables service is watching.
        Arguments:
        """
        def end_getRepository(self, _r):
            return _M_omero.grid.Tables._op_getRepository.end(self, _r)

        """
        Returns the Table service for the given ""OMERO.tables"" file.
        This service will open the file locally to access the data.
        After any modification, the file will be saved locally and
        the server asked to update the database record. This is done
        via services in the omero.api.ServiceFactory.
        Arguments:
        file -- 
        sf -- 
        _ctx -- The request context for the invocation.
        """
        def getTable(self, file, sf, _ctx=None):
            return _M_omero.grid.Tables._op_getTable.invoke(self, ((file, sf), _ctx))

        """
        Returns the Table service for the given ""OMERO.tables"" file.
        This service will open the file locally to access the data.
        After any modification, the file will be saved locally and
        the server asked to update the database record. This is done
        via services in the omero.api.ServiceFactory.
        Arguments:
        file -- 
        sf -- 
        _response -- The asynchronous response callback.
        _ex -- The asynchronous exception callback.
        _sent -- The asynchronous sent callback.
        _ctx -- The request context for the invocation.
        Returns: An asynchronous result object for the invocation.
        """
        def begin_getTable(self, file, sf, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.grid.Tables._op_getTable.begin(self, ((file, sf), _response, _ex, _sent, _ctx))

        """
        Returns the Table service for the given ""OMERO.tables"" file.
        This service will open the file locally to access the data.
        After any modification, the file will be saved locally and
        the server asked to update the database record. This is done
        via services in the omero.api.ServiceFactory.
        Arguments:
        file -- 
        sf -- 
        """
        def end_getTable(self, _r):
            return _M_omero.grid.Tables._op_getTable.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.grid.TablesPrx.ice_checkedCast(proxy, '::omero::grid::Tables', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.grid.TablesPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::grid::Tables'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.grid._t_TablesPrx = IcePy.defineProxy('::omero::grid::Tables', TablesPrx)

    _M_omero.grid._t_Tables = IcePy.defineClass('::omero::grid::Tables', Tables, -1, (), True, False, None, (), ())
    Tables._ice_type = _M_omero.grid._t_Tables

    Tables._op_getRepository = IcePy.Operation('getRepository', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (), (), ((), _M_omero.grid._t_RepositoryPrx, False, 0), (_M_omero._t_ServerError,))
    Tables._op_getTable = IcePy.Operation('getTable', Ice.OperationMode.Idempotent, Ice.OperationMode.Idempotent, False, None, (), (((), _M_omero.model._t_OriginalFile, False, 0), ((), _M_omero.api._t_ServiceFactoryPrx, False, 0)), (), ((), _M_omero.grid._t_TablePrx, False, 0), (_M_omero._t_ServerError,))

    _M_omero.grid.Tables = Tables
    del Tables

    _M_omero.grid.TablesPrx = TablesPrx
    del TablesPrx

# End of module omero.grid

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Shape.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Roi' not in _M_omero.model.__dict__:
    _M_omero.model._t_Roi = IcePy.declareClass('::omero::model::Roi')
    _M_omero.model._t_RoiPrx = IcePy.declareProxy('::omero::model::Roi')

if 'AffineTransform' not in _M_omero.model.__dict__:
    _M_omero.model._t_AffineTransform = IcePy.declareClass('::omero::model::AffineTransform')
    _M_omero.model._t_AffineTransformPrx = IcePy.declareProxy('::omero::model::AffineTransform')

if 'Length' not in _M_omero.model.__dict__:
    _M_omero.model._t_Length = IcePy.declareClass('::omero::model::Length')
    _M_omero.model._t_LengthPrx = IcePy.declareProxy('::omero::model::Length')

if 'ShapeAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_ShapeAnnotationLink = IcePy.declareClass('::omero::model::ShapeAnnotationLink')
    _M_omero.model._t_ShapeAnnotationLinkPrx = IcePy.declareProxy('::omero::model::ShapeAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_ShapeAnnotationLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ShapeAnnotationLinksSeq = IcePy.defineSequence('::omero::model::ShapeAnnotationLinksSeq', (), _M_omero.model._t_ShapeAnnotationLink)

if '_t_ShapeLinkedAnnotationSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_ShapeLinkedAnnotationSeq = IcePy.defineSequence('::omero::model::ShapeLinkedAnnotationSeq', (), _M_omero.model._t_Annotation)

if 'Shape' not in _M_omero.model.__dict__:
    _M_omero.model.Shape = Ice.createTempClass()
    class Shape(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _theZ=None, _theT=None, _theC=None, _roi=None, _locked=None, _transform=None, _fillColor=None, _fillRule=None, _strokeColor=None, _strokeDashArray=None, _strokeWidth=None, _fontFamily=None, _fontSize=None, _fontStyle=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None):
            if Ice.getType(self) == _M_omero.model.Shape:
                raise RuntimeError('omero.model.Shape is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._theZ = _theZ
            self._theT = _theT
            self._theC = _theC
            self._roi = _roi
            self._locked = _locked
            self._transform = _transform
            self._fillColor = _fillColor
            self._fillRule = _fillRule
            self._strokeColor = _strokeColor
            self._strokeDashArray = _strokeDashArray
            self._strokeWidth = _strokeWidth
            self._fontFamily = _fontFamily
            self._fontSize = _fontSize
            self._fontStyle = _fontStyle
            self._annotationLinksSeq = _annotationLinksSeq
            self._annotationLinksLoaded = _annotationLinksLoaded
            self._annotationLinksCountPerOwner = _annotationLinksCountPerOwner

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::Shape')

        def ice_id(self, current=None):
            return '::omero::model::Shape'

        def ice_staticId():
            return '::omero::model::Shape'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getTheZ(self, current=None):
            pass

        def setTheZ(self, theTheZ, current=None):
            pass

        def getTheT(self, current=None):
            pass

        def setTheT(self, theTheT, current=None):
            pass

        def getTheC(self, current=None):
            pass

        def setTheC(self, theTheC, current=None):
            pass

        def getRoi(self, current=None):
            pass

        def setRoi(self, theRoi, current=None):
            pass

        def getLocked(self, current=None):
            pass

        def setLocked(self, theLocked, current=None):
            pass

        def getTransform(self, current=None):
            pass

        def setTransform(self, theTransform, current=None):
            pass

        def getFillColor(self, current=None):
            pass

        def setFillColor(self, theFillColor, current=None):
            pass

        def getFillRule(self, current=None):
            pass

        def setFillRule(self, theFillRule, current=None):
            pass

        def getStrokeColor(self, current=None):
            pass

        def setStrokeColor(self, theStrokeColor, current=None):
            pass

        def getStrokeDashArray(self, current=None):
            pass

        def setStrokeDashArray(self, theStrokeDashArray, current=None):
            pass

        def getStrokeWidth(self, current=None):
            pass

        def setStrokeWidth(self, theStrokeWidth, current=None):
            pass

        def getFontFamily(self, current=None):
            pass

        def setFontFamily(self, theFontFamily, current=None):
            pass

        def getFontSize(self, current=None):
            pass

        def setFontSize(self, theFontSize, current=None):
            pass

        def getFontStyle(self, current=None):
            pass

        def setFontStyle(self, theFontStyle, current=None):
            pass

        def unloadAnnotationLinks(self, current=None):
            pass

        def sizeOfAnnotationLinks(self, current=None):
            pass

        def copyAnnotationLinks(self, current=None):
            pass

        def addShapeAnnotationLink(self, target, current=None):
            pass

        def addAllShapeAnnotationLinkSet(self, targets, current=None):
            pass

        def removeShapeAnnotationLink(self, theTarget, current=None):
            pass

        def removeAllShapeAnnotationLinkSet(self, targets, current=None):
            pass

        def clearAnnotationLinks(self, current=None):
            pass

        def reloadAnnotationLinks(self, toCopy, current=None):
            pass

        def getAnnotationLinksCountPerOwner(self, current=None):
            pass

        def linkAnnotation(self, addition, current=None):
            pass

        def addShapeAnnotationLinkToBoth(self, link, bothSides, current=None):
            pass

        def findShapeAnnotationLink(self, removal, current=None):
            pass

        def unlinkAnnotation(self, removal, current=None):
            pass

        def removeShapeAnnotationLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedAnnotationList(self, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Shape)

        __repr__ = __str__

    _M_omero.model.ShapePrx = Ice.createTempClass()
    class ShapePrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.Shape._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.Shape._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.Shape._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.Shape._op_setVersion.end(self, _r)

        def getTheZ(self, _ctx=None):
            return _M_omero.model.Shape._op_getTheZ.invoke(self, ((), _ctx))

        def begin_getTheZ(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getTheZ.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTheZ(self, _r):
            return _M_omero.model.Shape._op_getTheZ.end(self, _r)

        def setTheZ(self, theTheZ, _ctx=None):
            return _M_omero.model.Shape._op_setTheZ.invoke(self, ((theTheZ, ), _ctx))

        def begin_setTheZ(self, theTheZ, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setTheZ.begin(self, ((theTheZ, ), _response, _ex, _sent, _ctx))

        def end_setTheZ(self, _r):
            return _M_omero.model.Shape._op_setTheZ.end(self, _r)

        def getTheT(self, _ctx=None):
            return _M_omero.model.Shape._op_getTheT.invoke(self, ((), _ctx))

        def begin_getTheT(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getTheT.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTheT(self, _r):
            return _M_omero.model.Shape._op_getTheT.end(self, _r)

        def setTheT(self, theTheT, _ctx=None):
            return _M_omero.model.Shape._op_setTheT.invoke(self, ((theTheT, ), _ctx))

        def begin_setTheT(self, theTheT, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setTheT.begin(self, ((theTheT, ), _response, _ex, _sent, _ctx))

        def end_setTheT(self, _r):
            return _M_omero.model.Shape._op_setTheT.end(self, _r)

        def getTheC(self, _ctx=None):
            return _M_omero.model.Shape._op_getTheC.invoke(self, ((), _ctx))

        def begin_getTheC(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getTheC.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTheC(self, _r):
            return _M_omero.model.Shape._op_getTheC.end(self, _r)

        def setTheC(self, theTheC, _ctx=None):
            return _M_omero.model.Shape._op_setTheC.invoke(self, ((theTheC, ), _ctx))

        def begin_setTheC(self, theTheC, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setTheC.begin(self, ((theTheC, ), _response, _ex, _sent, _ctx))

        def end_setTheC(self, _r):
            return _M_omero.model.Shape._op_setTheC.end(self, _r)

        def getRoi(self, _ctx=None):
            return _M_omero.model.Shape._op_getRoi.invoke(self, ((), _ctx))

        def begin_getRoi(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getRoi.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRoi(self, _r):
            return _M_omero.model.Shape._op_getRoi.end(self, _r)

        def setRoi(self, theRoi, _ctx=None):
            return _M_omero.model.Shape._op_setRoi.invoke(self, ((theRoi, ), _ctx))

        def begin_setRoi(self, theRoi, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setRoi.begin(self, ((theRoi, ), _response, _ex, _sent, _ctx))

        def end_setRoi(self, _r):
            return _M_omero.model.Shape._op_setRoi.end(self, _r)

        def getLocked(self, _ctx=None):
            return _M_omero.model.Shape._op_getLocked.invoke(self, ((), _ctx))

        def begin_getLocked(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getLocked.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getLocked(self, _r):
            return _M_omero.model.Shape._op_getLocked.end(self, _r)

        def setLocked(self, theLocked, _ctx=None):
            return _M_omero.model.Shape._op_setLocked.invoke(self, ((theLocked, ), _ctx))

        def begin_setLocked(self, theLocked, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setLocked.begin(self, ((theLocked, ), _response, _ex, _sent, _ctx))

        def end_setLocked(self, _r):
            return _M_omero.model.Shape._op_setLocked.end(self, _r)

        def getTransform(self, _ctx=None):
            return _M_omero.model.Shape._op_getTransform.invoke(self, ((), _ctx))

        def begin_getTransform(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getTransform.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTransform(self, _r):
            return _M_omero.model.Shape._op_getTransform.end(self, _r)

        def setTransform(self, theTransform, _ctx=None):
            return _M_omero.model.Shape._op_setTransform.invoke(self, ((theTransform, ), _ctx))

        def begin_setTransform(self, theTransform, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setTransform.begin(self, ((theTransform, ), _response, _ex, _sent, _ctx))

        def end_setTransform(self, _r):
            return _M_omero.model.Shape._op_setTransform.end(self, _r)

        def getFillColor(self, _ctx=None):
            return _M_omero.model.Shape._op_getFillColor.invoke(self, ((), _ctx))

        def begin_getFillColor(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getFillColor.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getFillColor(self, _r):
            return _M_omero.model.Shape._op_getFillColor.end(self, _r)

        def setFillColor(self, theFillColor, _ctx=None):
            return _M_omero.model.Shape._op_setFillColor.invoke(self, ((theFillColor, ), _ctx))

        def begin_setFillColor(self, theFillColor, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setFillColor.begin(self, ((theFillColor, ), _response, _ex, _sent, _ctx))

        def end_setFillColor(self, _r):
            return _M_omero.model.Shape._op_setFillColor.end(self, _r)

        def getFillRule(self, _ctx=None):
            return _M_omero.model.Shape._op_getFillRule.invoke(self, ((), _ctx))

        def begin_getFillRule(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getFillRule.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getFillRule(self, _r):
            return _M_omero.model.Shape._op_getFillRule.end(self, _r)

        def setFillRule(self, theFillRule, _ctx=None):
            return _M_omero.model.Shape._op_setFillRule.invoke(self, ((theFillRule, ), _ctx))

        def begin_setFillRule(self, theFillRule, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setFillRule.begin(self, ((theFillRule, ), _response, _ex, _sent, _ctx))

        def end_setFillRule(self, _r):
            return _M_omero.model.Shape._op_setFillRule.end(self, _r)

        def getStrokeColor(self, _ctx=None):
            return _M_omero.model.Shape._op_getStrokeColor.invoke(self, ((), _ctx))

        def begin_getStrokeColor(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getStrokeColor.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getStrokeColor(self, _r):
            return _M_omero.model.Shape._op_getStrokeColor.end(self, _r)

        def setStrokeColor(self, theStrokeColor, _ctx=None):
            return _M_omero.model.Shape._op_setStrokeColor.invoke(self, ((theStrokeColor, ), _ctx))

        def begin_setStrokeColor(self, theStrokeColor, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setStrokeColor.begin(self, ((theStrokeColor, ), _response, _ex, _sent, _ctx))

        def end_setStrokeColor(self, _r):
            return _M_omero.model.Shape._op_setStrokeColor.end(self, _r)

        def getStrokeDashArray(self, _ctx=None):
            return _M_omero.model.Shape._op_getStrokeDashArray.invoke(self, ((), _ctx))

        def begin_getStrokeDashArray(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getStrokeDashArray.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getStrokeDashArray(self, _r):
            return _M_omero.model.Shape._op_getStrokeDashArray.end(self, _r)

        def setStrokeDashArray(self, theStrokeDashArray, _ctx=None):
            return _M_omero.model.Shape._op_setStrokeDashArray.invoke(self, ((theStrokeDashArray, ), _ctx))

        def begin_setStrokeDashArray(self, theStrokeDashArray, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setStrokeDashArray.begin(self, ((theStrokeDashArray, ), _response, _ex, _sent, _ctx))

        def end_setStrokeDashArray(self, _r):
            return _M_omero.model.Shape._op_setStrokeDashArray.end(self, _r)

        def getStrokeWidth(self, _ctx=None):
            return _M_omero.model.Shape._op_getStrokeWidth.invoke(self, ((), _ctx))

        def begin_getStrokeWidth(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getStrokeWidth.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getStrokeWidth(self, _r):
            return _M_omero.model.Shape._op_getStrokeWidth.end(self, _r)

        def setStrokeWidth(self, theStrokeWidth, _ctx=None):
            return _M_omero.model.Shape._op_setStrokeWidth.invoke(self, ((theStrokeWidth, ), _ctx))

        def begin_setStrokeWidth(self, theStrokeWidth, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setStrokeWidth.begin(self, ((theStrokeWidth, ), _response, _ex, _sent, _ctx))

        def end_setStrokeWidth(self, _r):
            return _M_omero.model.Shape._op_setStrokeWidth.end(self, _r)

        def getFontFamily(self, _ctx=None):
            return _M_omero.model.Shape._op_getFontFamily.invoke(self, ((), _ctx))

        def begin_getFontFamily(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getFontFamily.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getFontFamily(self, _r):
            return _M_omero.model.Shape._op_getFontFamily.end(self, _r)

        def setFontFamily(self, theFontFamily, _ctx=None):
            return _M_omero.model.Shape._op_setFontFamily.invoke(self, ((theFontFamily, ), _ctx))

        def begin_setFontFamily(self, theFontFamily, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setFontFamily.begin(self, ((theFontFamily, ), _response, _ex, _sent, _ctx))

        def end_setFontFamily(self, _r):
            return _M_omero.model.Shape._op_setFontFamily.end(self, _r)

        def getFontSize(self, _ctx=None):
            return _M_omero.model.Shape._op_getFontSize.invoke(self, ((), _ctx))

        def begin_getFontSize(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getFontSize.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getFontSize(self, _r):
            return _M_omero.model.Shape._op_getFontSize.end(self, _r)

        def setFontSize(self, theFontSize, _ctx=None):
            return _M_omero.model.Shape._op_setFontSize.invoke(self, ((theFontSize, ), _ctx))

        def begin_setFontSize(self, theFontSize, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setFontSize.begin(self, ((theFontSize, ), _response, _ex, _sent, _ctx))

        def end_setFontSize(self, _r):
            return _M_omero.model.Shape._op_setFontSize.end(self, _r)

        def getFontStyle(self, _ctx=None):
            return _M_omero.model.Shape._op_getFontStyle.invoke(self, ((), _ctx))

        def begin_getFontStyle(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getFontStyle.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getFontStyle(self, _r):
            return _M_omero.model.Shape._op_getFontStyle.end(self, _r)

        def setFontStyle(self, theFontStyle, _ctx=None):
            return _M_omero.model.Shape._op_setFontStyle.invoke(self, ((theFontStyle, ), _ctx))

        def begin_setFontStyle(self, theFontStyle, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_setFontStyle.begin(self, ((theFontStyle, ), _response, _ex, _sent, _ctx))

        def end_setFontStyle(self, _r):
            return _M_omero.model.Shape._op_setFontStyle.end(self, _r)

        def unloadAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Shape._op_unloadAnnotationLinks.invoke(self, ((), _ctx))

        def begin_unloadAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_unloadAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadAnnotationLinks(self, _r):
            return _M_omero.model.Shape._op_unloadAnnotationLinks.end(self, _r)

        def sizeOfAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Shape._op_sizeOfAnnotationLinks.invoke(self, ((), _ctx))

        def begin_sizeOfAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_sizeOfAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfAnnotationLinks(self, _r):
            return _M_omero.model.Shape._op_sizeOfAnnotationLinks.end(self, _r)

        def copyAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Shape._op_copyAnnotationLinks.invoke(self, ((), _ctx))

        def begin_copyAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_copyAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyAnnotationLinks(self, _r):
            return _M_omero.model.Shape._op_copyAnnotationLinks.end(self, _r)

        def addShapeAnnotationLink(self, target, _ctx=None):
            return _M_omero.model.Shape._op_addShapeAnnotationLink.invoke(self, ((target, ), _ctx))

        def begin_addShapeAnnotationLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_addShapeAnnotationLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addShapeAnnotationLink(self, _r):
            return _M_omero.model.Shape._op_addShapeAnnotationLink.end(self, _r)

        def addAllShapeAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Shape._op_addAllShapeAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllShapeAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_addAllShapeAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllShapeAnnotationLinkSet(self, _r):
            return _M_omero.model.Shape._op_addAllShapeAnnotationLinkSet.end(self, _r)

        def removeShapeAnnotationLink(self, theTarget, _ctx=None):
            return _M_omero.model.Shape._op_removeShapeAnnotationLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeShapeAnnotationLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_removeShapeAnnotationLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeShapeAnnotationLink(self, _r):
            return _M_omero.model.Shape._op_removeShapeAnnotationLink.end(self, _r)

        def removeAllShapeAnnotationLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Shape._op_removeAllShapeAnnotationLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllShapeAnnotationLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_removeAllShapeAnnotationLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllShapeAnnotationLinkSet(self, _r):
            return _M_omero.model.Shape._op_removeAllShapeAnnotationLinkSet.end(self, _r)

        def clearAnnotationLinks(self, _ctx=None):
            return _M_omero.model.Shape._op_clearAnnotationLinks.invoke(self, ((), _ctx))

        def begin_clearAnnotationLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_clearAnnotationLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearAnnotationLinks(self, _r):
            return _M_omero.model.Shape._op_clearAnnotationLinks.end(self, _r)

        def reloadAnnotationLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Shape._op_reloadAnnotationLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadAnnotationLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_reloadAnnotationLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadAnnotationLinks(self, _r):
            return _M_omero.model.Shape._op_reloadAnnotationLinks.end(self, _r)

        def getAnnotationLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Shape._op_getAnnotationLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getAnnotationLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_getAnnotationLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAnnotationLinksCountPerOwner(self, _r):
            return _M_omero.model.Shape._op_getAnnotationLinksCountPerOwner.end(self, _r)

        def linkAnnotation(self, addition, _ctx=None):
            return _M_omero.model.Shape._op_linkAnnotation.invoke(self, ((addition, ), _ctx))

        def begin_linkAnnotation(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_linkAnnotation.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkAnnotation(self, _r):
            return _M_omero.model.Shape._op_linkAnnotation.end(self, _r)

        def addShapeAnnotationLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Shape._op_addShapeAnnotationLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addShapeAnnotationLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_addShapeAnnotationLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addShapeAnnotationLinkToBoth(self, _r):
            return _M_omero.model.Shape._op_addShapeAnnotationLinkToBoth.end(self, _r)

        def findShapeAnnotationLink(self, removal, _ctx=None):
            return _M_omero.model.Shape._op_findShapeAnnotationLink.invoke(self, ((removal, ), _ctx))

        def begin_findShapeAnnotationLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_findShapeAnnotationLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findShapeAnnotationLink(self, _r):
            return _M_omero.model.Shape._op_findShapeAnnotationLink.end(self, _r)

        def unlinkAnnotation(self, removal, _ctx=None):
            return _M_omero.model.Shape._op_unlinkAnnotation.invoke(self, ((removal, ), _ctx))

        def begin_unlinkAnnotation(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_unlinkAnnotation.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkAnnotation(self, _r):
            return _M_omero.model.Shape._op_unlinkAnnotation.end(self, _r)

        def removeShapeAnnotationLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Shape._op_removeShapeAnnotationLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeShapeAnnotationLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_removeShapeAnnotationLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeShapeAnnotationLinkFromBoth(self, _r):
            return _M_omero.model.Shape._op_removeShapeAnnotationLinkFromBoth.end(self, _r)

        def linkedAnnotationList(self, _ctx=None):
            return _M_omero.model.Shape._op_linkedAnnotationList.invoke(self, ((), _ctx))

        def begin_linkedAnnotationList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Shape._op_linkedAnnotationList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedAnnotationList(self, _r):
            return _M_omero.model.Shape._op_linkedAnnotationList.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.ShapePrx.ice_checkedCast(proxy, '::omero::model::Shape', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.ShapePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Shape'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_ShapePrx = IcePy.defineProxy('::omero::model::Shape', ShapePrx)

    _M_omero.model._t_Shape = IcePy.declareClass('::omero::model::Shape')

    _M_omero.model._t_Shape = IcePy.defineClass('::omero::model::Shape', Shape, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_theZ', (), _M_omero._t_RInt, False, 0),
        ('_theT', (), _M_omero._t_RInt, False, 0),
        ('_theC', (), _M_omero._t_RInt, False, 0),
        ('_roi', (), _M_omero.model._t_Roi, False, 0),
        ('_locked', (), _M_omero._t_RBool, False, 0),
        ('_transform', (), _M_omero.model._t_AffineTransform, False, 0),
        ('_fillColor', (), _M_omero._t_RInt, False, 0),
        ('_fillRule', (), _M_omero._t_RString, False, 0),
        ('_strokeColor', (), _M_omero._t_RInt, False, 0),
        ('_strokeDashArray', (), _M_omero._t_RString, False, 0),
        ('_strokeWidth', (), _M_omero.model._t_Length, False, 0),
        ('_fontFamily', (), _M_omero._t_RString, False, 0),
        ('_fontSize', (), _M_omero.model._t_Length, False, 0),
        ('_fontStyle', (), _M_omero._t_RString, False, 0),
        ('_annotationLinksSeq', (), _M_omero.model._t_ShapeAnnotationLinksSeq, False, 0),
        ('_annotationLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_annotationLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0)
    ))
    Shape._ice_type = _M_omero.model._t_Shape

    Shape._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Shape._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Shape._op_getTheZ = IcePy.Operation('getTheZ', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Shape._op_setTheZ = IcePy.Operation('setTheZ', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Shape._op_getTheT = IcePy.Operation('getTheT', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Shape._op_setTheT = IcePy.Operation('setTheT', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Shape._op_getTheC = IcePy.Operation('getTheC', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Shape._op_setTheC = IcePy.Operation('setTheC', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Shape._op_getRoi = IcePy.Operation('getRoi', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Roi, False, 0), ())
    Shape._op_setRoi = IcePy.Operation('setRoi', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Roi, False, 0),), (), None, ())
    Shape._op_getLocked = IcePy.Operation('getLocked', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RBool, False, 0), ())
    Shape._op_setLocked = IcePy.Operation('setLocked', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RBool, False, 0),), (), None, ())
    Shape._op_getTransform = IcePy.Operation('getTransform', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_AffineTransform, False, 0), ())
    Shape._op_setTransform = IcePy.Operation('setTransform', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_AffineTransform, False, 0),), (), None, ())
    Shape._op_getFillColor = IcePy.Operation('getFillColor', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Shape._op_setFillColor = IcePy.Operation('setFillColor', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Shape._op_getFillRule = IcePy.Operation('getFillRule', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Shape._op_setFillRule = IcePy.Operation('setFillRule', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Shape._op_getStrokeColor = IcePy.Operation('getStrokeColor', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Shape._op_setStrokeColor = IcePy.Operation('setStrokeColor', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Shape._op_getStrokeDashArray = IcePy.Operation('getStrokeDashArray', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Shape._op_setStrokeDashArray = IcePy.Operation('setStrokeDashArray', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Shape._op_getStrokeWidth = IcePy.Operation('getStrokeWidth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    Shape._op_setStrokeWidth = IcePy.Operation('setStrokeWidth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    Shape._op_getFontFamily = IcePy.Operation('getFontFamily', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Shape._op_setFontFamily = IcePy.Operation('setFontFamily', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Shape._op_getFontSize = IcePy.Operation('getFontSize', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    Shape._op_setFontSize = IcePy.Operation('setFontSize', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    Shape._op_getFontStyle = IcePy.Operation('getFontStyle', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Shape._op_setFontStyle = IcePy.Operation('setFontStyle', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Shape._op_unloadAnnotationLinks = IcePy.Operation('unloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Shape._op_sizeOfAnnotationLinks = IcePy.Operation('sizeOfAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Shape._op_copyAnnotationLinks = IcePy.Operation('copyAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ShapeAnnotationLinksSeq, False, 0), ())
    Shape._op_addShapeAnnotationLink = IcePy.Operation('addShapeAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ShapeAnnotationLink, False, 0),), (), None, ())
    Shape._op_addAllShapeAnnotationLinkSet = IcePy.Operation('addAllShapeAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ShapeAnnotationLinksSeq, False, 0),), (), None, ())
    Shape._op_removeShapeAnnotationLink = IcePy.Operation('removeShapeAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ShapeAnnotationLink, False, 0),), (), None, ())
    Shape._op_removeAllShapeAnnotationLinkSet = IcePy.Operation('removeAllShapeAnnotationLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ShapeAnnotationLinksSeq, False, 0),), (), None, ())
    Shape._op_clearAnnotationLinks = IcePy.Operation('clearAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Shape._op_reloadAnnotationLinks = IcePy.Operation('reloadAnnotationLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Shape, False, 0),), (), None, ())
    Shape._op_getAnnotationLinksCountPerOwner = IcePy.Operation('getAnnotationLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Shape._op_linkAnnotation = IcePy.Operation('linkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_ShapeAnnotationLink, False, 0), ())
    Shape._op_addShapeAnnotationLinkToBoth = IcePy.Operation('addShapeAnnotationLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ShapeAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Shape._op_findShapeAnnotationLink = IcePy.Operation('findShapeAnnotationLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), ((), _M_omero.model._t_ShapeAnnotationLinksSeq, False, 0), ())
    Shape._op_unlinkAnnotation = IcePy.Operation('unlinkAnnotation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Annotation, False, 0),), (), None, ())
    Shape._op_removeShapeAnnotationLinkFromBoth = IcePy.Operation('removeShapeAnnotationLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ShapeAnnotationLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Shape._op_linkedAnnotationList = IcePy.Operation('linkedAnnotationList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ShapeLinkedAnnotationSeq, False, 0), ())

    _M_omero.model.Shape = Shape
    del Shape

    _M_omero.model.ShapePrx = ShapePrx
    del ShapePrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (C) 2015 Glencoe Software, Inc. All Rights Reserved.
# Use is subject to license terms supplied in LICENSE.txt
#

"""
   chown plugin

   Plugin read by omero.cli.Cli during initialization. The method(s)
   defined here will be added to the Cli class for later use.
"""

from omero.cli import CLI, GraphControl, ExperimenterArg, GraphArg
import sys

HELP = """Transfer ownership of data between users. Entire graphs of data,
based on the ID of the top-node, are transferred.

There are two ways to use this command, either specify the data to be
transferred or specify users from whom the ownership of all their data
will be transferred. These two usage ways can be combined.

The usage with specified users has to be considered as advanced usage
and might potentially be slow.

This command can only be used by OMERO administrators and group owners.

Group owners can only transfer ownership between members of the owned group.
Administrators can transfer ownership between any users regardless of their
respective groups.

Note that after transferring ownership the data will remain in their original
group. Thus it is possible for an administrator to make the data unavailable
to the new user. In such cases the data must be moved to one of the user's
groups or the user must be added to the group that the data is in.

Examples:

    # In each case transfer the ownership of an image to user 101
    omero chown 101 Image:1
    omero chown User:101 Image:2
    omero chown Experimenter:101 Image:3
    # In both cases transfer five images to the user named jane
    omero chown jane Image:51,52,53,54,56
    omero chown jane Image:51-54,56

    # Transfer a plate but leave all images with the original owner
    omero chown 201 Plate:1 --exclude Image

    # Transfer all images contained under a project
    omero chown 101 Project/Dataset/Image:53
    # Transfer all images contained under two projects
    omero chown 101 Project/Image:201,202

    # Advanced usage & potentially slow:
    # Transfer all data owned by user 111 and one image to user 4
    omero chown 4 Experimenter:111 Image:17
    # Advanced usage & potentially slow:
    # Transfer all data of users 1, 3 and 7 to user 10
    omero chown 10 Experimenter:1,3,7

    # Do a dry run of a transfer reporting the outcome
    # if the transfer had been run
    omero chown 101 Dataset:53 --dry-run
    # Do a dry run of a transfer, reporting all the objects
    # that would have been transferred
    omero chown 101 Dataset:53 --dry-run --report

"""


class ChownControl(GraphControl):

    def cmd_type(self):
        import omero
        import omero.all
        return omero.cmd.Chown2

    def _pre_objects(self, parser):
        parser.add_argument(
            "usr", nargs="?", type=ExperimenterArg,
            help="user to transfer ownership of specified objects and/or all"
                 " objects owned by specified user(s) to")

    def _objects(self, parser):
        parser.add_argument(
            "obj", nargs="*", type=GraphArg(self.cmd_type()),
            help="objects to be processed in the form <Class>:<Id>"
                 " and/or user(s) to transfer all data from in the"
                 " form Experimenter:<Id>")

    def populate_target_users(self, command_check):
        """
        Move the Experimenters whose data are to be
        transferred from targetObjects
        to targetUsers. The rewritten _check_command
        method checked these Experimenters when they were
        in targetObjects, but Chown2 needs them in targetUsers.
        """
        try:
            command_check.targetUsers = command_check.targetObjects.pop(
                "Experimenter")
        except KeyError:
            pass

    def _check_command(self, command_check):
        """
        Rewrite higher class method to have command check
        as well as the possibility to adjust the command.
        """
        super(ChownControl, self)._check_command(command_check)
        self.populate_target_users(command_check)

    def _process_request(self, req, args, client):
        # Retrieve user id
        uid = args.usr.lookup(client)
        if uid is None:
            self.ctx.die(196, "Failed to find user: %s" % args.usr.orig)

        # Set requests user
        import omero
        if isinstance(req, omero.cmd.DoAll):
            for request in req.requests:
                if isinstance(request, omero.cmd.SkipHead):
                    request.request.userId = uid
                else:
                    request.userId = uid
        else:
            if isinstance(req, omero.cmd.SkipHead):
                req.request.userId = uid
            else:
                req.userId = uid

        super(ChownControl, self)._process_request(req, args, client)

    def print_detailed_report(self, req, rsp, status):
        import omero
        if isinstance(rsp, omero.cmd.DoAllRsp):
            for response in rsp.responses:
                if isinstance(response, omero.cmd.Chown2Response):
                    self.print_chown_response(response)
        elif isinstance(rsp, omero.cmd.Chown2Response):
            self.print_chown_response(rsp)

    def print_chown_response(self, rsp):
        if rsp.includedObjects:
            self.ctx.out("Included objects")
            objIds = self._get_object_ids(rsp.includedObjects)
            for k in objIds:
                self.ctx.out("  %s:%s" % (k, objIds[k]))
        if rsp.deletedObjects:
            self.ctx.out("Deleted objects")
            objIds = self._get_object_ids(rsp.deletedObjects)
            for k in objIds:
                self.ctx.out("  %s:%s" % (k, objIds[k]))

try:
    register("chown", ChownControl, HELP)
except NameError:
    if __name__ == "__main__":
        cli = CLI()
        cli.register("chown", ChownControl, HELP)
        cli.invoke(sys.argv[1:])



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `TransmittanceRange.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Length' not in _M_omero.model.__dict__:
    _M_omero.model._t_Length = IcePy.declareClass('::omero::model::Length')
    _M_omero.model._t_LengthPrx = IcePy.declareProxy('::omero::model::Length')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'TransmittanceRange' not in _M_omero.model.__dict__:
    _M_omero.model.TransmittanceRange = Ice.createTempClass()
    class TransmittanceRange(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _cutIn=None, _cutOut=None, _cutInTolerance=None, _cutOutTolerance=None, _transmittance=None):
            if Ice.getType(self) == _M_omero.model.TransmittanceRange:
                raise RuntimeError('omero.model.TransmittanceRange is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._cutIn = _cutIn
            self._cutOut = _cutOut
            self._cutInTolerance = _cutInTolerance
            self._cutOutTolerance = _cutOutTolerance
            self._transmittance = _transmittance

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::TransmittanceRange')

        def ice_id(self, current=None):
            return '::omero::model::TransmittanceRange'

        def ice_staticId():
            return '::omero::model::TransmittanceRange'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getCutIn(self, current=None):
            pass

        def setCutIn(self, theCutIn, current=None):
            pass

        def getCutOut(self, current=None):
            pass

        def setCutOut(self, theCutOut, current=None):
            pass

        def getCutInTolerance(self, current=None):
            pass

        def setCutInTolerance(self, theCutInTolerance, current=None):
            pass

        def getCutOutTolerance(self, current=None):
            pass

        def setCutOutTolerance(self, theCutOutTolerance, current=None):
            pass

        def getTransmittance(self, current=None):
            pass

        def setTransmittance(self, theTransmittance, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_TransmittanceRange)

        __repr__ = __str__

    _M_omero.model.TransmittanceRangePrx = Ice.createTempClass()
    class TransmittanceRangePrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.TransmittanceRange._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.TransmittanceRange._op_setVersion.end(self, _r)

        def getCutIn(self, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_getCutIn.invoke(self, ((), _ctx))

        def begin_getCutIn(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_getCutIn.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getCutIn(self, _r):
            return _M_omero.model.TransmittanceRange._op_getCutIn.end(self, _r)

        def setCutIn(self, theCutIn, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_setCutIn.invoke(self, ((theCutIn, ), _ctx))

        def begin_setCutIn(self, theCutIn, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_setCutIn.begin(self, ((theCutIn, ), _response, _ex, _sent, _ctx))

        def end_setCutIn(self, _r):
            return _M_omero.model.TransmittanceRange._op_setCutIn.end(self, _r)

        def getCutOut(self, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_getCutOut.invoke(self, ((), _ctx))

        def begin_getCutOut(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_getCutOut.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getCutOut(self, _r):
            return _M_omero.model.TransmittanceRange._op_getCutOut.end(self, _r)

        def setCutOut(self, theCutOut, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_setCutOut.invoke(self, ((theCutOut, ), _ctx))

        def begin_setCutOut(self, theCutOut, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_setCutOut.begin(self, ((theCutOut, ), _response, _ex, _sent, _ctx))

        def end_setCutOut(self, _r):
            return _M_omero.model.TransmittanceRange._op_setCutOut.end(self, _r)

        def getCutInTolerance(self, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_getCutInTolerance.invoke(self, ((), _ctx))

        def begin_getCutInTolerance(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_getCutInTolerance.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getCutInTolerance(self, _r):
            return _M_omero.model.TransmittanceRange._op_getCutInTolerance.end(self, _r)

        def setCutInTolerance(self, theCutInTolerance, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_setCutInTolerance.invoke(self, ((theCutInTolerance, ), _ctx))

        def begin_setCutInTolerance(self, theCutInTolerance, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_setCutInTolerance.begin(self, ((theCutInTolerance, ), _response, _ex, _sent, _ctx))

        def end_setCutInTolerance(self, _r):
            return _M_omero.model.TransmittanceRange._op_setCutInTolerance.end(self, _r)

        def getCutOutTolerance(self, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_getCutOutTolerance.invoke(self, ((), _ctx))

        def begin_getCutOutTolerance(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_getCutOutTolerance.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getCutOutTolerance(self, _r):
            return _M_omero.model.TransmittanceRange._op_getCutOutTolerance.end(self, _r)

        def setCutOutTolerance(self, theCutOutTolerance, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_setCutOutTolerance.invoke(self, ((theCutOutTolerance, ), _ctx))

        def begin_setCutOutTolerance(self, theCutOutTolerance, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_setCutOutTolerance.begin(self, ((theCutOutTolerance, ), _response, _ex, _sent, _ctx))

        def end_setCutOutTolerance(self, _r):
            return _M_omero.model.TransmittanceRange._op_setCutOutTolerance.end(self, _r)

        def getTransmittance(self, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_getTransmittance.invoke(self, ((), _ctx))

        def begin_getTransmittance(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_getTransmittance.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTransmittance(self, _r):
            return _M_omero.model.TransmittanceRange._op_getTransmittance.end(self, _r)

        def setTransmittance(self, theTransmittance, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_setTransmittance.invoke(self, ((theTransmittance, ), _ctx))

        def begin_setTransmittance(self, theTransmittance, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.TransmittanceRange._op_setTransmittance.begin(self, ((theTransmittance, ), _response, _ex, _sent, _ctx))

        def end_setTransmittance(self, _r):
            return _M_omero.model.TransmittanceRange._op_setTransmittance.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.TransmittanceRangePrx.ice_checkedCast(proxy, '::omero::model::TransmittanceRange', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.TransmittanceRangePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::TransmittanceRange'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_TransmittanceRangePrx = IcePy.defineProxy('::omero::model::TransmittanceRange', TransmittanceRangePrx)

    _M_omero.model._t_TransmittanceRange = IcePy.declareClass('::omero::model::TransmittanceRange')

    _M_omero.model._t_TransmittanceRange = IcePy.defineClass('::omero::model::TransmittanceRange', TransmittanceRange, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_cutIn', (), _M_omero.model._t_Length, False, 0),
        ('_cutOut', (), _M_omero.model._t_Length, False, 0),
        ('_cutInTolerance', (), _M_omero.model._t_Length, False, 0),
        ('_cutOutTolerance', (), _M_omero.model._t_Length, False, 0),
        ('_transmittance', (), _M_omero._t_RDouble, False, 0)
    ))
    TransmittanceRange._ice_type = _M_omero.model._t_TransmittanceRange

    TransmittanceRange._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    TransmittanceRange._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    TransmittanceRange._op_getCutIn = IcePy.Operation('getCutIn', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    TransmittanceRange._op_setCutIn = IcePy.Operation('setCutIn', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    TransmittanceRange._op_getCutOut = IcePy.Operation('getCutOut', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    TransmittanceRange._op_setCutOut = IcePy.Operation('setCutOut', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    TransmittanceRange._op_getCutInTolerance = IcePy.Operation('getCutInTolerance', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    TransmittanceRange._op_setCutInTolerance = IcePy.Operation('setCutInTolerance', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    TransmittanceRange._op_getCutOutTolerance = IcePy.Operation('getCutOutTolerance', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    TransmittanceRange._op_setCutOutTolerance = IcePy.Operation('setCutOutTolerance', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    TransmittanceRange._op_getTransmittance = IcePy.Operation('getTransmittance', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    TransmittanceRange._op_setTransmittance = IcePy.Operation('setTransmittance', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())

    _M_omero.model.TransmittanceRange = TransmittanceRange
    del TransmittanceRange

    _M_omero.model.TransmittanceRangePrx = TransmittanceRangePrx
    del TransmittanceRangePrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright 2009-2016 University of Dundee. All rights reserved.
# Use is subject to license terms supplied in LICENSE.txt

"""
windows helper plugin

"""

from functools import wraps

WINDOWS_WARNING = ("ERROR: OMERO.server support for Windows was removed"
                   " in OMERO 5.3, see http://blog.openmicroscopy.org/"
                   "tech-issues/future-plans/deployment/2016/03/22/"
                   "windows-support/")


def windows_warning(func):
    """
    Support for Windows will be removed
    """
    def win_warn(func):
        def wrapper(self, *args, **kwargs):
            if self._isWindows():
                self.ctx.die(20, WINDOWS_WARNING)
            return func(self, *args, **kwargs)
        return wrapper
    return wraps(func)(win_warn(func))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# ------------------------------------------------------------------------------
#  Copyright (C) 2006-2008 University of Dundee. All rights reserved.
#
#
# 	This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License along
#  with this program; if not, write to the Free Software Foundation, Inc.,
#  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# ------------------------------------------------------------------------------
#
# The Pixels object in omero, has a member pixelsType, this can be
#    INT_8 = "int8";
#    UINT_8 = "uint8";
#    INT_16 = "int16";
#    UINT_16 = "uint16";
#    INT_32 = "int32";
#    UINT_32 = "uint32";
#    FLOAT = "float";
#    DOUBLE = "double";
# we can convert these to the appropriate types in python.

from omero.model.enums import PixelsTypeint8, PixelsTypeuint8, PixelsTypeint16
from omero.model.enums import PixelsTypeuint16, PixelsTypeint32
from omero.model.enums import PixelsTypeuint32, PixelsTypefloat
from omero.model.enums import PixelsTypedouble

INT_8 = PixelsTypeint8
UINT_8 = PixelsTypeuint8
INT_16 = PixelsTypeint16
UINT_16 = PixelsTypeuint16
INT_32 = PixelsTypeint32
UINT_32 = PixelsTypeuint32
FLOAT = PixelsTypefloat
DOUBLE = PixelsTypedouble


def toPython(pixelType):
    if(pixelType == INT_8):
        return 'b'
    if(pixelType == UINT_8):
        return 'B'
    if(pixelType == INT_16):
        return 'h'
    if(pixelType == UINT_16):
        return 'H'
    if(pixelType == INT_32):
        return 'i'
    if(pixelType == UINT_32):
        return 'I'
    if(pixelType == FLOAT):
        return 'f'
    if(pixelType == DOUBLE):
        return 'd'


def toNumpy(pixelType):
    import numpy
    if(pixelType == INT_8):
        return numpy.int8
    if(pixelType == UINT_8):
        return numpy.uint8
    if(pixelType == INT_16):
        return numpy.int16
    if(pixelType == UINT_16):
        return numpy.uint16
    if(pixelType == INT_32):
        return numpy.int32
    if(pixelType == UINT_32):
        return numpy.uint32
    if(pixelType == FLOAT):
        return numpy.float
    if(pixelType == DOUBLE):
        return numpy.double


def toArray(pixelType):
    if(pixelType == INT_8):
        return 'b'
    if(pixelType == UINT_8):
        return 'B'
    if(pixelType == INT_16):
        return 'i2'
    if(pixelType == UINT_16):
        return 'H2'
    if(pixelType == INT_32):
        return 'i4'
    if(pixelType == UINT_32):
        return 'I4'
    if(pixelType == FLOAT):
        return 'f'
    if(pixelType == DOUBLE):
        return 'd'


def toPIL(pixelType):
    if(pixelType == INT_8):
        return 'L'
    if(pixelType == UINT_8):
        return 'L'
    if(pixelType == INT_16):
        return 'I;16'
    if(pixelType == UINT_16):
        return 'I;16'
    if(pixelType == INT_32):
        return 'I'
    if(pixelType == UINT_32):
        return 'I'
    if(pixelType == FLOAT):
        return 'F'
    if(pixelType == DOUBLE):
        return 'F'
